==> haskell-project-template-0.2.0-54-i686.pkg.tar.xz: usr/share/haskell/register/haskell-project-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: project-template
version: 0.2.0
id: project-template-0.2.0-9nMHnPOJKxxKo4Q8p5N8ne
key: project-template-0.2.0-9nMHnPOJKxxKo4Q8p5N8ne
license: BSD3
maintainer: michael@fpcomplete.com
homepage: https://github.com/fpco/haskell-ide
synopsis: Specify Haskell project templates and generate files
description:
    See initial blog post for explanation: <http://www.yesodweb.com/blog/2012/09/project-templates>
category: Development
author: Michael Snoyman
exposed: True
exposed-modules:
    Text.ProjectTemplate
abi: 81fb7fe97d1091bf2da0fce34644209f
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/project-template-0.2.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/project-template-0.2.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/project-template-0.2.0
hs-libraries: HSproject-template-0.2.0-9nMHnPOJKxxKo4Q8p5N8ne
depends:
    base-4.9.0.0 base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    bytestring-0.10.8.1 conduit-1.2.10-JpwcbBZZrSj1n2q4Mh3BJS
    conduit-extra-1.1.16-LbHEhSYrKrIKl2iEItQ5UA containers-0.5.7.1
    directory-1.2.6.2 filepath-1.4.1.0 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-project-template/html/project-template.haddock
haddock-html: /usr/share/doc/haskell-project-template/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-project-template-0.2.0-62-i686.pkg.tar.xz: usr/share/haskell/register/haskell-project-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: project-template
version: 0.2.0
id: project-template-0.2.0-C97VtP12YPz9hFItTyy8tH
key: project-template-0.2.0-C97VtP12YPz9hFItTyy8tH
license: BSD3
maintainer: michael@fpcomplete.com
homepage: https://github.com/fpco/haskell-ide
synopsis: Specify Haskell project templates and generate files
description:
    See initial blog post for explanation: <http://www.yesodweb.com/blog/2012/09/project-templates>
category: Development
author: Michael Snoyman
exposed: True
exposed-modules:
    Text.ProjectTemplate
abi: f1eca4854d71f2007180f09b3242c336
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/project-template-0.2.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/project-template-0.2.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/project-template-0.2.0
hs-libraries: HSproject-template-0.2.0-C97VtP12YPz9hFItTyy8tH
depends:
    base-4.9.0.0 base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    bytestring-0.10.8.1 conduit-1.2.11-67QBPVFU7Mu9oEC9xc41Cq
    conduit-extra-1.1.16-848Xd70hoN45Ueua8FUxsp containers-0.5.7.1
    directory-1.2.6.2 filepath-1.4.1.0 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    resourcet-1.1.9-4wjmwiYhI4Y4ny0clYPjM8
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-project-template/html/project-template.haddock
haddock-html: /usr/share/doc/haskell-project-template/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
